@@ -149,13 +149,22 @@ class FeatureGroupVersion(AbstractApiClass):
 
     def wait_for_results(self, timeout=3600):
         """
-        A waiting call until feature group version is created.
+        A waiting call until feature group version is materialized
 
         Args:
-            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out. Default value given is 3600 milliseconds.
+            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
         """
         return self.client._poll(self, {'PENDING'}, timeout=timeout)
 
+    def wait_for_materialization(self, timeout=3600):
+        """
+        A waiting call until feature group version is materialized.
+
+        Args:
+            timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
+        """
+        return self.wait_for_results(timeout)
+
     def get_status(self):
         """
         Gets the status of the feature group version.
