@@ -218,7 +218,7 @@ class Project(AbstractApiClass):
         """
         return self.client.train_model(self.project_id, name, training_config, feature_group_ids, refresh_schedule)
 
-    def create_model_from_python(self, function_source_code: str, train_function_name: str, predict_function_name: str, training_input_tables: list, name: str = None, cpu_size: str = None, memory: int = None, training_config: dict = None, exclusive_run: bool = False, package_requirements: dict = None):
+    def create_model_from_python(self, function_source_code: str, train_function_name: str, predict_function_name: str, training_input_tables: list, predict_many_function_name: str = None, initialize_function_name: str = None, name: str = None, cpu_size: str = None, memory: int = None, training_config: dict = None, exclusive_run: bool = False, package_requirements: dict = None):
         """
         Initializes a new Model from user provided Python code. If a list of input feature groups are supplied,
 
@@ -236,6 +236,8 @@ class Project(AbstractApiClass):
             train_function_name (str): Name of the function found in the source code that will be executed to train the model. It is not executed when this function is run.
             predict_function_name (str): Name of the function found in the source code that will be executed run predictions through model. It is not executed when this function is run.
             training_input_tables (list): List of feature groups that are supplied to the train function as parameters. Each of the parameters are materialized Dataframes (same type as the functions return value).
+            predict_many_function_name (str): Name of the function found in the source code that will be executed for batch prediction of the model. It is not executed when this function is run.
+            initialize_function_name (str): Name of the function found in the source code to initialize the trained model before using it to make predictions using the model
             name (str): The name you want your model to have. Defaults to "<Project Name> Model"
             cpu_size (str): Size of the cpu for the model training function
             memory (int): Memory (in GB) for the model training function
@@ -246,7 +248,7 @@ class Project(AbstractApiClass):
         Returns:
             Model: The new model, which has not been trained.
         """
-        return self.client.create_model_from_python(self.project_id, function_source_code, train_function_name, predict_function_name, training_input_tables, name, cpu_size, memory, training_config, exclusive_run, package_requirements)
+        return self.client.create_model_from_python(self.project_id, function_source_code, train_function_name, predict_function_name, training_input_tables, predict_many_function_name, initialize_function_name, name, cpu_size, memory, training_config, exclusive_run, package_requirements)
 
     def create_model_from_zip(self, train_function_name: str, predict_function_name: str, train_module_name: str, predict_module_name: str, training_input_tables: list, name: str = None, cpu_size: str = None, memory: int = None, package_requirements: dict = None):
         """
@@ -440,7 +442,7 @@ class Project(AbstractApiClass):
         """
         return self.client.remove_dataset_from_project(dataset_id, self.project_id)
 
-    def create_model_from_functions(self, train_function: callable, predict_function: callable, training_input_tables: list = None):
+    def create_model_from_functions(self, train_function: callable, predict_function: callable, training_input_tables: list = None, predict_many_function: callable = None, initialize_function: callable = None, cpu_size: str = None, memory: int = None, training_config: dict = None, exclusive_run: bool = False):
         """
         Creates a model using python.
 
@@ -448,8 +450,10 @@ class Project(AbstractApiClass):
             train_function (callable): The train function is passed.
             predict_function (callable): The prediction function is passed.
             training_input_tables (list, optional): The input tables to be used for training the model. Defaults to None.
+            cpu_size (str): Size of the cpu for the feature group function
+            memory (int): Memory (in GB) for the feature group function
 
         Returns:
             Model: The model object.
         """
-        return self.client.create_model_from_functions(self.project_id, train_function, predict_function, training_input_tables)
+        return self.client.create_model_from_functions(project_id=self.id, train_function=train_function, predict_function=predict_function, training_input_tables=training_input_tables, predict_many_function=predict_many_function, initialize_function=initialize_function, training_config=training_config, cpu_size=cpu_size, memory=memory, exclusive_run=exclusive_run)
